@@ -16,7 +16,7 @@ from .api import Api
 import requests
 import os
 
-__version__ = "1.5.18"
+__version__ = "1.5.24"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
@@ -56,6 +56,10 @@ def reload_jobs():
     webhook.manager.reload_jobs()
 
 
+def run(path=None, debug=False):
+    return webhook.run(path, debug)
+
+
 def move_job(old_path, new_path):
     webhook.manager.move_job(old_path, new_path)
 
