@@ -90,8 +90,8 @@ class Api:
             pass
         url = self.manager.proxy_url(self.role, token)
         if self.manager.is_production():
-            print("No add done, you are in production\n")
-            return url
+            print("No run done, you are in production\n")
+            return
         self.manager.add_prod(
             {
                 "type": self.role,
@@ -110,7 +110,7 @@ class Api:
             print("😢 Your Notebook failed in production.\n")
         self.get_output(path)
         self.manager.del_prod({"type": self.role, "path": current_file}, debug)
-        return url
+        return
 
     def find(self, path=None):
         current_file = self.manager.get_path(path)
@@ -214,7 +214,7 @@ class Api:
             raise TypeError("data shoud be a dataframe")
         display(HTML(data.to_html(), metadata={"naas_api": True, "naas_type": "csv"}))
 
-    def delete(self, path=None, all=False, debug=False):
+    def delete(self, path=None, all=True, debug=False):
         self.deprecatedPrint()
         if self.manager.is_production():
             print("No delete done, you are in production\n")
@@ -223,5 +223,5 @@ class Api:
         self.manager.del_prod({"type": self.role, "path": current_file}, debug)
         print("🗑 Done! Your Notebook has been remove from production.\n")
         if all is True:
-            self.clear(path)
-            self.clear_output(path)
+            self.clear(current_file, "all")
+            self.clear_output(current_file, "all")
